@@ -1,6 +1,8 @@
+import ssl
 import sys
 from argparse import ArgumentParser, Namespace
-from urllib.error import HTTPError
+from http.client import RemoteDisconnected
+from urllib.error import HTTPError, URLError
 from urllib.request import urlopen
 
 
@@ -19,14 +21,23 @@ def parse_args():
         type=float, default=0.3,
         help="timeout before connection fail"
     )
+    parser.add_argument(
+        "--allow-unverified", action="store_true",
+        help="allows for invalid self-signed certificates to be valid"
+    )
     return parser.parse_args()
 
 
 def main(args: Namespace):
+    ssl_context = None
+    if args.allow_unverified:
+        ssl_context = ssl._create_unverified_context()
+
     try:
         with urlopen(
             args.url,
             timeout=args.timeout,
+            context=ssl_context,
         ) as response:
             if response.read().decode() != "🆗":
                 eprint(f"⛔ missing '🆗' in response")
@@ -35,6 +46,10 @@ def main(args: Namespace):
                 return
     except HTTPError as err:
         eprint(f"⛔ http status '{err.code}'")
+    except URLError as err:
+        eprint(f"⛔ url error '{err.reason}'")
+    except RemoteDisconnected:
+        eprint(f"⛔ remote closed without response")
 
     exit(1)
 
